@@ -158,11 +158,6 @@ QFuture<VideoListResult> InvidiousApi::requestFeed(Paginator *paginator)
     return requestVideoList(Feed, QStringLiteral(""), {}, paginator);
 }
 
-QFuture<VideoListResult> InvidiousApi::requestTop()
-{
-    return requestVideoList(Top);
-}
-
 QFuture<VideoListResult> InvidiousApi::requestTrending(TrendingTopic topic, Paginator *paginator)
 {
     QHash<QString, QString> parameters;
@@ -391,6 +386,11 @@ QFuture<Result> InvidiousApi::removeVideoFromPlaylist(const QString &plid, const
     return deleteResource<Result>(authenticatedNetworkRequest(std::move(url)), checkIsReplyOk);
 }
 
+QString InvidiousApi::getVideoUrl(const QString &videoId)
+{
+    return QStringLiteral("https://youtube.com/watch?v=%1").arg(videoId);
+}
+
 Error InvidiousApi::invalidJsonError()
 {
     return {QNetworkReply::InternalServerError, i18n("Server returned no valid JSON.")};
