@@ -133,11 +133,6 @@ QFuture<VideoListResult> PipedApi::requestFeed(Paginator *paginator)
     return {};
 }
 
-QFuture<VideoListResult> PipedApi::requestTop()
-{
-    return {};
-}
-
 QFuture<VideoListResult> PipedApi::requestTrending(TrendingTopic topic, Paginator *paginator)
 {
     Q_UNUSED(paginator)
@@ -321,6 +316,11 @@ QFuture<Result> PipedApi::removeVideoFromPlaylist(const QString &plid, const QSt
     return {};
 }
 
+QString PipedApi::getVideoUrl(const QString &videoId)
+{
+    return QStringLiteral("https://youtube.com/watch?v=%1").arg(videoId);
+}
+
 Error PipedApi::invalidJsonError()
 {
     return {QNetworkReply::InternalServerError, i18n("Server returned no valid JSON.")};
